export interface AutoURLDataSyncInProps<Data> {
    readonly data: Data;
    readonly dataError: Error | null | undefined;
    readonly isLoadingData: boolean;
    readonly urlQuery: URLQueryMap;
    saveData(): void;
    updateData(data: Partial<Data>): void;
    /** Update URL query parameters without reloading and trigger a re-sync. */
    updateURLQuery(...queries: readonly URLQueryMap[]): void;
}
export interface AutoURLDataSyncOutProps<Data> {
    /** This is used for the data synchronizer. */
    readonly additionalDataQuery?: Repository.URLDataSync.AdditionalQuery;
    readonly initialData: Data;
    readonly urlDataSync: Repository.URLDataSync;
    readonly onDataChange?: (data: Data) => void;
}
export interface AutoURLDataSyncEnhancer<Data> extends FunctionalEnhancer<AutoURLDataSyncInProps<Data>, AutoURLDataSyncOutProps<Data>> {
}
/**
 * Automatically sync with current URL by requesting data from server using
 * said URL. This is assuming there is data provided by the server at current
 * URL, e.g. user navigates to /users/1, this will send a GET request to
 * /users/1, which should have a defined backend route that contains the
 * relevant data.
 *
 * This HOC is usually used for components rendered by a Route. Please make sure
 * when implementing the backend to handle these requests that it never returns
 * null/undefined (as per REST design standards).
 */
export declare function autoURLDataSync<Data>(): AutoURLDataSyncEnhancer<Data>;
interface MongoCursorPaginatedData<Data> {
    readonly results: Data;
    readonly count: number;
    readonly next?: string;
    readonly previous?: string;
}
export interface MongoCursorPaginationInProps<Data> extends Pick<AutoURLDataSyncOutProps<MongoCursorPaginatedData<Data>>, "additionalDataQuery" | "onDataChange"> {
    readonly page: number;
}
export interface MongoCursorPaginationEnhancer<Data> extends FunctionalEnhancer<MongoCursorPaginationInProps<Data>, {}> {
}
/**
 * This works with the auto-sync HOC to provide paginated data. It is assumed
 * that the server will return the data in the above format - the cursor markers
 * will be stored internally and fed the next time we perform a GET request.
 */
export declare function mongoCursorPagination<Data>(): MongoCursorPaginationEnhancer<Data>;
export {};
//# sourceMappingURL=dataHOC.d.ts.map